summaryrefslogtreecommitdiffstats
path: root/src/utils/probe.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/utils/probe.py')
-rw-r--r--src/utils/probe.py11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/utils/probe.py b/src/utils/probe.py
index 8c0e39a..b2ed5de 100644
--- a/src/utils/probe.py
+++ b/src/utils/probe.py
@@ -135,14 +135,17 @@ def get_linux_distro_id(mountpoint):
logging.error(f'os-release file not found at "{osrelease}"')
return 'linux'
-def cache_probe():
+def get_cache_dev_path():
"""
Runs 'blkid -L CACHE' and returns stripped stdout
"""
proc_blkid = subprocess.run(['blkid', '-L', 'CACHE'],
stdout=subprocess.PIPE)
- stdout = proc_blkid.stdout.decode().strip()
- return stdout
+ if proc_blkid.returncode != 0:
+ logging.error('Cannot find device path to cache')
+ return ''
+
+ return proc_blkid.stdout.decode().strip()
def get_os_family(mountpoint):
@@ -135,14 +135,17 @@ def get_linux_distro_id(mountpoint):
"""
- Runs 'blkid -L CACHE' and returns stripped stdout
+ Runs 'blkid -L CACHE' and returns stripped path to device, eg. /dev/sda3
"""
proc_blkid = subprocess.run(['blkid', '-L', 'CACHE'],